<?php

namespace FiloBlu\Storelocator\Api\Plugin\Sales;


class OrderManagementInterface {

    protected $_helper;
    protected $_quoteFactory;
    protected $_orderRepository;
    protected $_transportBuilder;
    protected $_storeManager;
    protected $_inlineTranslation;
    protected $_paymentHelper;
    protected $_addressRenderer;

    public function __construct(
    \FiloBlu\Storelocator\Helper\Data $helper,
    \Magento\Quote\Model\QuoteFactory $quoteFactory,
    \Magento\Sales\Api\OrderRepositoryInterface $orderRepository,
    \Magento\Framework\Mail\Template\TransportBuilder $transportBuilder,
    \Magento\Store\Model\StoreManagerInterface $storeManager,
    \Magento\Framework\Translate\Inline\StateInterface $inlineTranslation,
    \Magento\Payment\Helper\Data $paymentHelper,
    \Magento\Sales\Model\Order\Address\Renderer $addressRenderer
    ) {
        $this->_helper = $helper;
        $this->_quoteFactory = $quoteFactory;
        $this->_orderRepository = $orderRepository;
        $this->_transportBuilder = $transportBuilder;
        $this->_storeManager = $storeManager;
        $this->_inlineTranslation = $inlineTranslation;
        $this->_paymentHelper = $paymentHelper;
        $this->_addressRenderer = $addressRenderer;
    }

    public function afterPlace($interceptor, $order) {

        if ($this->_helper->getConfig("carriers/pickup_in_store/active")) {

          $quote = null;

          if ($order->getQuoteId()) {
              $quote = $this->_quoteFactory->create()->load($order->getQuoteId());
          }

          // Save PickUp Store Information
          try {
              if ($quote && $quote->getPickupInStoreId() && $quote->getPickupInStoreEmail() && $quote->getShippingAddress() && $quote->getShippingAddress()->getShippingMethod() == "pickup_in_store_pickup_in_store") {

                $order->setPickupInStoreId($quote->getPickupInStoreId());
                $order->setPickupInStoreEmail($quote->getPickupInStoreEmail());
                $order->setPickupInStoreHash(md5(time()));
                $this->_orderRepository->save($order);

                // Send mail to store
                $this->sendMail($order);

              }
          } catch (\Exception $ex) {

          }

        }

        return $order;

    }

    protected function sendMail($order) {
      if (!$this->_helper->getConfig("carriers/pickup_in_store/email_to_store_enabled")) {
        return;
      }

      $this->_inlineTranslation->suspend();

      $billingAddress = $order->getBillingAddress();

      $templateVars = [
        'order' => $order,
        'billing' => $billingAddress,
        'payment_html' => $this->getPaymentHtml($order),
        'store' => $order->getStore(),
        'formattedShippingAddress' => $this->getFormattedShippingAddress($order),
        'formattedBillingAddress' => $this->getFormattedBillingAddress($order),
      ];

      $templateOptions = [
          'area' => \Magento\Framework\App\Area::AREA_FRONTEND,
          'store' => $this->_storeManager->getStore()->getStoreId(),
      ];

      try {
          $transport = $this->_transportBuilder
              ->setTemplateIdentifier($this->_helper->getConfig("carriers/pickup_in_store/email_to_store_template"))
              ->setTemplateOptions($templateOptions)
              ->setTemplateVars($templateVars)
              ->setFrom($this->_helper->getConfig("carriers/pickup_in_store/sender_email_to_store_identity"))
              ->addTo($order->getPickupInStoreEmail())
              ->getTransport();
          $transport->sendMessage();

          $this->_inlineTranslation->resume();

      } catch (\Exception $e) {
          $this->_inlineTranslation->resume();
      }
    }

    protected function getPaymentHtml($order)
    {
        return $this->_paymentHelper->getInfoBlockHtml(
            $order->getPayment(),
            $this->_storeManager->getStore()->getId()
        );
    }

    protected function getFormattedShippingAddress($order)
    {
        return $order->getIsVirtual()
            ? null
            : $this->_addressRenderer->format($order->getShippingAddress(), 'html');
    }

    protected function getFormattedBillingAddress($order)
    {
        return $this->_addressRenderer->format($order->getBillingAddress(), 'html');
    }
}
